@@ -1,4 +1,5 @@
 import asyncio
+from datetime import timezone
 from typing import cast, Optional
 
 import discord
@@ -104,20 +105,17 @@ class MuteMixin(MixinMeta):
 
         guild = ctx.guild
         author = ctx.author
-        try:
-            await modlog.create_case(
-                self.bot,
-                guild,
-                ctx.message.created_at,
-                "voiceunban",
-                user,
-                author,
-                reason,
-                until=None,
-                channel=None,
-            )
-        except RuntimeError as e:
-            await ctx.send(e)
+        await modlog.create_case(
+            self.bot,
+            guild,
+            ctx.message.created_at.replace(tzinfo=timezone.utc),
+            "voiceunban",
+            user,
+            author,
+            reason,
+            until=None,
+            channel=None,
+        )
         await ctx.send(_("User is now allowed to speak and listen in voice channels"))
 
     @commands.command()
@@ -148,20 +146,17 @@ class MuteMixin(MixinMeta):
             await ctx.send(_("That user is already muted and deafened server-wide!"))
             return
 
-        try:
-            await modlog.create_case(
-                self.bot,
-                guild,
-                ctx.message.created_at,
-                "voiceban",
-                user,
-                author,
-                reason,
-                until=None,
-                channel=None,
-            )
-        except RuntimeError as e:
-            await ctx.send(e)
+        await modlog.create_case(
+            self.bot,
+            guild,
+            ctx.message.created_at.replace(tzinfo=timezone.utc),
+            "voiceban",
+            user,
+            author,
+            reason,
+            until=None,
+            channel=None,
+        )
         await ctx.send(_("User has been banned from speaking or listening in voice channels"))
 
     @commands.group()
@@ -191,20 +186,17 @@ class MuteMixin(MixinMeta):
         success, issue = await self.mute_user(guild, channel, author, user, audit_reason)
 
         if success:
-            try:
-                await modlog.create_case(
-                    self.bot,
-                    guild,
-                    ctx.message.created_at,
-                    "vmute",
-                    user,
-                    author,
-                    reason,
-                    until=None,
-                    channel=channel,
-                )
-            except RuntimeError as e:
-                await ctx.send(e)
+            await modlog.create_case(
+                self.bot,
+                guild,
+                ctx.message.created_at.replace(tzinfo=timezone.utc),
+                "vmute",
+                user,
+                author,
+                reason,
+                until=None,
+                channel=channel,
+            )
             await ctx.send(
                 _("Muted {user} in channel {channel.name}").format(user=user, channel=channel)
             )
@@ -238,20 +230,17 @@ class MuteMixin(MixinMeta):
         success, issue = await self.mute_user(guild, channel, author, user, audit_reason)
 
         if success:
-            try:
-                await modlog.create_case(
-                    self.bot,
-                    guild,
-                    ctx.message.created_at,
-                    "cmute",
-                    user,
-                    author,
-                    reason,
-                    until=None,
-                    channel=channel,
-                )
-            except RuntimeError as e:
-                await ctx.send(e)
+            await modlog.create_case(
+                self.bot,
+                guild,
+                ctx.message.created_at.replace(tzinfo=timezone.utc),
+                "cmute",
+                user,
+                author,
+                reason,
+                until=None,
+                channel=channel,
+            )
             await channel.send(_("User has been muted in this channel."))
         else:
             await channel.send(issue)
@@ -274,7 +263,7 @@ class MuteMixin(MixinMeta):
             await modlog.create_case(
                 self.bot,
                 guild,
-                ctx.message.created_at,
+                ctx.message.created_at.replace(tzinfo=timezone.utc),
                 "smute",
                 user,
                 author,
@@ -314,20 +303,17 @@ class MuteMixin(MixinMeta):
         success, message = await self.unmute_user(guild, channel, author, user, audit_reason)
 
         if success:
-            try:
-                await modlog.create_case(
-                    self.bot,
-                    guild,
-                    ctx.message.created_at,
-                    "vunmute",
-                    user,
-                    author,
-                    reason,
-                    until=None,
-                    channel=channel,
-                )
-            except RuntimeError as e:
-                await ctx.send(e)
+            await modlog.create_case(
+                self.bot,
+                guild,
+                ctx.message.created_at.replace(tzinfo=timezone.utc),
+                "vunmute",
+                user,
+                author,
+                reason,
+                until=None,
+                channel=channel,
+            )
             await ctx.send(
                 _("Unmuted {user} in channel {channel.name}").format(user=user, channel=channel)
             )
@@ -361,20 +347,17 @@ class MuteMixin(MixinMeta):
         success, message = await self.unmute_user(guild, channel, author, user, audit_reason)
 
         if success:
-            try:
-                await modlog.create_case(
-                    self.bot,
-                    guild,
-                    ctx.message.created_at,
-                    "cunmute",
-                    user,
-                    author,
-                    reason,
-                    until=None,
-                    channel=channel,
-                )
-            except RuntimeError as e:
-                await ctx.send(e)
+            await modlog.create_case(
+                self.bot,
+                guild,
+                ctx.message.created_at.replace(tzinfo=timezone.utc),
+                "cunmute",
+                user,
+                author,
+                reason,
+                until=None,
+                channel=channel,
+            )
             await ctx.send(_("User unmuted in this channel."))
         else:
             await ctx.send(_("Unmute failed. Reason: {}").format(message))
@@ -401,7 +384,7 @@ class MuteMixin(MixinMeta):
             await modlog.create_case(
                 self.bot,
                 guild,
-                ctx.message.created_at,
+                ctx.message.created_at.replace(tzinfo=timezone.utc),
                 "sunmute",
                 user,
                 author,
