@@ -1,18 +1,19 @@
 from __future__ import annotations
 
 import asyncio
-import datetime
-from typing import Union, List, Optional, TYPE_CHECKING
+import logging
+from datetime import datetime, timezone
+from typing import Union, List, Optional, TYPE_CHECKING, Literal
 from functools import wraps
 
 import discord
 
+from redbot.core.utils import AsyncIter
 from redbot.core.utils.chat_formatting import humanize_number
 from . import Config, errors, commands
 from .i18n import Translator
 
 from .errors import BankPruneError
-from .utils import AsyncIter
 
 if TYPE_CHECKING:
     from .bot import Red
@@ -67,6 +68,10 @@ _DEFAULT_USER = _DEFAULT_MEMBER
 
 _config: Config = None
 
+log = logging.getLogger("red.core.bank")
+
+_data_deletion_lock = asyncio.Lock()
+
 
 def _init():
     global _config
@@ -77,12 +82,34 @@ def _init():
     _config.register_user(**_DEFAULT_USER)
 
 
+async def _process_data_deletion(
+    *, requester: Literal["discord_deleted_user", "owner", "user", "user_strict"], user_id: int
+):
+    """
+    Bank has no reason to keep any of this data
+    if the user doesn't want it kept,
+    we won't special case any request type
+    """
+    if requester not in ("discord_deleted_user", "owner", "user", "user_strict"):
+        log.warning(
+            "Got unknown data request type `{req_type}` for user, deleting anyway",
+            req_type=requester,
+        )
+
+    async with _data_deletion_lock:
+        await _config.user_from_id(user_id).clear()
+        all_members = await _config.all_members()
+        async for guild_id, member_dict in AsyncIter(all_members.items(), steps=100):
+            if user_id in member_dict:
+                await _config.member_from_ids(guild_id, user_id).clear()
+
+
 class Account:
     """A single account.
 
     This class should ONLY be instantiated by the bank itself."""
 
-    def __init__(self, name: str, balance: int, created_at: datetime.datetime):
+    def __init__(self, name: str, balance: int, created_at: datetime):
         self.name = name
         self.balance = balance
         self.created_at = created_at
@@ -90,25 +117,25 @@ class Account:
 
 def _encoded_current_time() -> int:
     """Get the current UTC time as a timestamp.
-    
+
     Returns
     -------
     int
         The current UTC timestamp.
 
     """
-    now = datetime.datetime.utcnow()
+    now = datetime.now(timezone.utc)
     return _encode_time(now)
 
 
-def _encode_time(time: datetime.datetime) -> int:
+def _encode_time(time: datetime) -> int:
     """Convert a datetime object to a serializable int.
-    
+
     Parameters
     ----------
     time : datetime.datetime
         The datetime to convert.
-        
+
     Returns
     -------
     int
@@ -119,21 +146,21 @@ def _encode_time(time: datetime.datetime) -> int:
     return ret
 
 
-def _decode_time(time: int) -> datetime.datetime:
+def _decode_time(time: int) -> datetime:
     """Convert a timestamp to a datetime object.
-    
+
     Parameters
     ----------
     time : int
         The timestamp to decode.
-        
+
     Returns
     -------
     datetime.datetime
         The datetime object from the timestamp.
 
     """
-    return datetime.datetime.utcfromtimestamp(time)
+    return datetime.utcfromtimestamp(time)
 
 
 async def get_balance(member: discord.Member) -> int:
