@@ -15,6 +15,7 @@ from .commands import (
     GroupMixin as GroupMixin,
     command as command,
     group as group,
+    RedUnhandledAPI as RedUnhandledAPI,
     RESERVED_COMMAND_NAMES as RESERVED_COMMAND_NAMES,
 )
 from .context import Context as Context, GuildContext as GuildContext, DMContext as DMContext
@@ -28,7 +29,6 @@ from .converter import (
     NoParseOptional as NoParseOptional,
     UserInputOptional as UserInputOptional,
     Literal as Literal,
-    __getattr__ as _converter__getattr__,  # this contains deprecation of APIToken
 )
 from .errors import (
     ConversionFailure as ConversionFailure,
@@ -75,6 +75,8 @@ from ._dpy_reimplements import (
     when_mentioned_or as when_mentioned_or,
     when_mentioned as when_mentioned,
     bot_has_any_role as bot_has_any_role,
+    before_invoke as before_invoke,
+    after_invoke as after_invoke,
 )
 
 ### DEP-WARN: Check this *every* discord.py update
@@ -142,15 +144,5 @@ from discord.ext.commands import (
     MaxConcurrency as MaxConcurrency,
     MaxConcurrencyReached as MaxConcurrencyReached,
     bot_has_guild_permissions as bot_has_guild_permissions,
+    CommandRegistrationError as CommandRegistrationError,
 )
-
-
-def __getattr__(name):
-    try:
-        return _converter__getattr__(name, stacklevel=3)
-    except AttributeError:
-        raise AttributeError(f"module {__name__!r} has no attribute {name!r}") from None
-
-
-def __dir__():
-    return [*globals().keys(), "APIToken"]
