@@ -2,13 +2,13 @@ from __future__ import annotations
 
 import asyncio
 import logging
-from datetime import datetime, timedelta
-from typing import List, Union, Optional, cast, TYPE_CHECKING
+from datetime import datetime, timedelta, timezone
+from typing import List, Literal, Union, Optional, cast, TYPE_CHECKING
 
 import discord
 
 from redbot.core import Config
-
+from .utils import AsyncIter
 from .utils.common_filters import (
     filter_invites,
     filter_mass_mentions,
@@ -47,10 +47,41 @@ _CASETYPES = "CASETYPES"
 _CASES = "CASES"
 _SCHEMA_VERSION = 4
 
+_data_deletion_lock = asyncio.Lock()
 
 _ = Translator("ModLog", __file__)
 
 
+async def _process_data_deletion(
+    *, requester: Literal["discord_deleted_user", "owner", "user", "user_strict"], user_id: int
+):
+    if requester != "discord_deleted_user":
+        return
+
+    # Oh, how I wish it was as simple as I wanted...
+
+    key_paths = []
+
+    async with _data_deletion_lock:
+        all_cases = await _config.custom(_CASES).all()
+        async for guild_id_str, guild_cases in AsyncIter(all_cases.items(), steps=100):
+            async for case_num_str, case in AsyncIter(guild_cases.items(), steps=100):
+                for keyname in ("user", "moderator", "amended_by"):
+                    if (case.get(keyname, 0) or 0) == user_id:  # this could be None...
+                        key_paths.append((guild_id_str, case_num_str))
+
+        async with _config.custom(_CASES).all() as all_cases:
+            for guild_id_str, case_num_str in key_paths:
+                case = all_cases[guild_id_str][case_num_str]
+                if (case.get("user", 0) or 0) == user_id:
+                    case["user"] = 0xDE1
+                    case.pop("last_known_username", None)
+                if (case.get("moderator", 0) or 0) == user_id:
+                    case["moderator"] = 0xDE1
+                if (case.get("amended_by", 0) or 0) == user_id:
+                    case["amended_by"] = 0xDE1
+
+
 async def _init(bot: Red):
     global _config
     global _bot_ref
@@ -96,7 +127,8 @@ async def _init(bot: Red):
                 if entry:
                     if entry.user.id != guild.me.id:
                         # Don't create modlog entires for the bot's own bans, cogs do this.
-                        mod, reason, date = entry.user, entry.reason, entry.created_at
+                        mod, reason = entry.user, entry.reason
+                        date = entry.created_at.replace(tzinfo=timezone.utc)
                         await create_case(_bot_ref, guild, date, "ban", member, mod, reason)
                     return
 
@@ -132,7 +164,8 @@ async def _init(bot: Red):
                 if entry:
                     if entry.user.id != guild.me.id:
                         # Don't create modlog entires for the bot's own unbans, cogs do this.
-                        mod, reason, date = entry.user, entry.reason, entry.created_at
+                        mod, reason = entry.user, entry.reason
+                        date = entry.created_at.replace(tzinfo=timezone.utc)
                         await create_case(_bot_ref, guild, date, "unban", user, mod, reason)
                     return
 
@@ -310,16 +343,19 @@ class Case:
             moderator = _("Unknown")
         elif isinstance(self.moderator, int):
             # can't use _() inside f-string expressions, see bpo-36310 and red#3818
-            translated = _("Unknown or Deleted User")
-            moderator = f"[{translated}] ({self.moderator})"
+            if self.moderator == 0xDE1:
+                moderator = _("Deleted User.")
+            else:
+                translated = _("Unknown or Deleted User")
+                moderator = f"[{translated}] ({self.moderator})"
         else:
             moderator = escape_spoilers(f"{self.moderator} ({self.moderator.id})")
         until = None
         duration = None
         if self.until:
-            start = datetime.fromtimestamp(self.created_at)
-            end = datetime.fromtimestamp(self.until)
-            end_fmt = end.strftime("%Y-%m-%d %H:%M:%S")
+            start = datetime.utcfromtimestamp(self.created_at)
+            end = datetime.utcfromtimestamp(self.until)
+            end_fmt = end.strftime("%Y-%m-%d %H:%M:%S UTC")
             duration = end - start
             dur_fmt = _strfdelta(duration)
             until = end_fmt
@@ -329,19 +365,24 @@ class Case:
             amended_by = None
         elif isinstance(self.amended_by, int):
             # can't use _() inside f-string expressions, see bpo-36310 and red#3818
-            translated = _("Unknown or Deleted User")
-            amended_by = f"[{translated}] ({self.amended_by})"
+            if self.amended_by == 0xDE1:
+                amended_by = _("Deleted User.")
+            else:
+                translated = _("Unknown or Deleted User")
+                amended_by = f"[{translated}] ({self.amended_by})"
         else:
             amended_by = escape_spoilers(f"{self.amended_by} ({self.amended_by.id})")
 
         last_modified = None
         if self.modified_at:
             last_modified = "{}".format(
-                datetime.fromtimestamp(self.modified_at).strftime("%Y-%m-%d %H:%M:%S")
+                datetime.utcfromtimestamp(self.modified_at).strftime("%Y-%m-%d %H:%M:%S UTC")
             )
 
         if isinstance(self.user, int):
-            if self.last_known_username is None:
+            if self.user == 0xDE1:
+                user = _("Deleted User.")
+            elif self.last_known_username is None:
                 # can't use _() inside f-string expressions, see bpo-36310 and red#3818
                 translated = _("Unknown or Deleted User")
                 user = f"[{translated}] ({self.user})"
@@ -374,7 +415,7 @@ class Case:
                 emb.add_field(name=_("Amended by"), value=amended_by)
             if last_modified:
                 emb.add_field(name=_("Last modified at"), value=last_modified)
-            emb.timestamp = datetime.fromtimestamp(self.created_at)
+            emb.timestamp = datetime.utcfromtimestamp(self.created_at)
             return emb
         else:
             user = filter_mass_mentions(filter_urls(user))  # Further sanitization outside embeds
